@@ -1,37 +1,37 @@
 
-/*  A Bison parser, made from ../../fsinfo/fsi_gram.y with Bison version GNU Bison version 1.24
-  */
+/*  A Bison parser, made from ../../fsinfo/fsi_gram.y
+    by GNU Bison version 1.28  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
-#define	tARCH	258
-#define	tAS	259
-#define	tAUTOMOUNT	260
-#define	tCLUSTER	261
-#define	tCONFIG	262
-#define	tDUMPSET	263
-#define	tEQ	264
-#define	tNFSEQ	265
-#define	tEXPORTFS	266
-#define	tFREQ	267
-#define	tFROM	268
-#define	tFS	269
-#define	tFSTYPE	270
-#define	tHWADDR	271
-#define	tINADDR	272
-#define	tHOST	273
-#define	tLOCALHOST	274
-#define	tLOG	275
-#define	tMOUNT	276
-#define	tNETMASK	277
-#define	tNETIF	278
-#define	tVOLNAME	279
-#define	tOPTS	280
-#define	tOS	281
-#define	tPASSNO	282
-#define	tDIRECT	283
-#define	tSEL	284
-#define	tSTR	285
+#define	tARCH	257
+#define	tAS	258
+#define	tAUTOMOUNT	259
+#define	tCLUSTER	260
+#define	tCONFIG	261
+#define	tDUMPSET	262
+#define	tEQ	263
+#define	tNFSEQ	264
+#define	tEXPORTFS	265
+#define	tFREQ	266
+#define	tFROM	267
+#define	tFS	268
+#define	tFSTYPE	269
+#define	tHWADDR	270
+#define	tINADDR	271
+#define	tHOST	272
+#define	tLOCALHOST	273
+#define	tLOG	274
+#define	tMOUNT	275
+#define	tNETMASK	276
+#define	tNETIF	277
+#define	tVOLNAME	278
+#define	tOPTS	279
+#define	tOS	280
+#define	tPASSNO	281
+#define	tDIRECT	282
+#define	tSEL	283
+#define	tSTR	284
 
 #line 45 "../../fsinfo/fsi_gram.y"
 
@@ -42,9 +42,25 @@
 #include <fsi_data.h>
 #include <fsinfo.h>
 
+/* AIX requires this to be the first thing in the file. */
+#ifndef __GNUC__
+# if HAVE_ALLOCA_H
+#  include <alloca.h>
+# else /* not HAVE_ALLOCA_H */
+#  ifdef _AIX
+#pragma alloca
+#  else /* not _AIX */
+#   ifndef alloca
+  /* predefined by HP cc +Olibcalls */
+voidp alloca();
+#   endif /* not alloca */
+#  endif /* not _AIX */
+# endif /* not HAVE_ALLOCA_H */
+#endif /* not __GNUC__ */
+
 extern qelem *list_of_hosts, *list_of_automounts;
 
-#line 56 "../../fsinfo/fsi_gram.y"
+#line 72 "../../fsinfo/fsi_gram.y"
 typedef union {
 	auto_tree *a;
 	disk_fs *d;
@@ -55,23 +71,6 @@ typedef union {
 	fsi_mount *m;
 	fsmount *f;
 } YYSTYPE;
-
-#ifndef YYLTYPE
-typedef
-  struct yyltype
-    {
-      int timestamp;
-      int first_line;
-      int first_column;
-      int last_line;
-      int last_column;
-      char *text;
-   }
-  yyltype;
-
-#define YYLTYPE yyltype
-#endif
-
 #include <stdio.h>
 
 #ifndef __cplusplus
@@ -86,7 +85,7 @@ typedef
 #define	YYFLAG		-32768
 #define	YYNTBASE	34
 
-#define YYTRANSLATE(x) ((unsigned)(x) <= 285 ? yytranslate[x] : 49)
+#define YYTRANSLATE(x) ((unsigned)(x) <= 284 ? yytranslate[x] : 49)
 
 static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -114,10 +113,10 @@ static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-     2,     2,     2,     2,     2,     1,     2,     3,     4,     5,
-     6,     7,     8,     9,    10,    11,    12,    13,    14,    15,
-    16,    17,    18,    19,    20,    21,    22,    23,    24,    25,
-    26,    27,    28,    29,    30
+     2,     2,     2,     2,     2,     1,     3,     4,     5,     6,
+     7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
+    17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
+    27,    28,    29,    30
 };
 
 #if YYDEBUG != 0
@@ -159,13 +158,17 @@ static const short yyrhs[] = {    -1,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   110,   114,   118,   128,   132,   137,   141,   146,   150,   156,
-   159,   162,   165,   168,   172,   176,   178,   180,   189,   198,
-   202,   206,   210,   214,   232,   236,   251,   255,   258,   261,
-   264,   267,   270,   273,   276,   289,   293,   303,   314,   324,
-   336,   340,   353,   357,   360,   363,   366,   375,   379,   398,
-   402,   405,   408,   411,   414,   417
+   126,   130,   134,   144,   148,   153,   157,   162,   166,   172,
+   175,   178,   181,   184,   188,   192,   194,   196,   205,   214,
+   218,   222,   226,   230,   248,   252,   267,   271,   274,   277,
+   280,   283,   286,   289,   292,   305,   309,   319,   330,   340,
+   352,   356,   369,   373,   376,   379,   382,   391,   395,   414,
+   418,   421,   424,   427,   430,   433
 };
+#endif
+
+
+#if YYDEBUG != 0 || defined (YYERROR_VERBOSE)
 
 static const char * const yytname[] = {   "$","error","$undefined.","tARCH",
 "tAS","tAUTOMOUNT","tCLUSTER","tCONFIG","tDUMPSET","tEQ","tNFSEQ","tEXPORTFS",
@@ -174,7 +177,7 @@ static const char * const yytname[] = {   "$","error","$undefined.","tARCH",
 "tSTR","'{'","'}'","'='","list_of_hosts","host","host_attr","host_attr_list",
 "ether_attr","automount","opt_auto_opts","list_of_filesystems","filesystem",
 "fs_info_list","automount_tree","dir_tree","dir_tree_info","list_of_mounts",
-"localinfo_list",""
+"localinfo_list", NULL
 };
 #endif
 
@@ -275,6 +278,7 @@ static const short yycheck[] = {     1,
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
 #line 3 "/usr/local/gnu/share/bison.simple"
+/* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -291,47 +295,67 @@ static const short yycheck[] = {     1,
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
    This special exception was added by the Free Software Foundation
    in version 1.24 of Bison.  */
 
-#ifndef alloca
-#ifdef __GNUC__
-#define alloca __builtin_alloca
-#else /* not GNU C.  */
-#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
-#include <alloca.h>
-#else /* not sparc */
-#if defined (MSDOS) && !defined (__TURBOC__)
-#include <malloc.h>
-#else /* not MSDOS, or __TURBOC__ */
-#if defined(_AIX)
-#include <malloc.h>
- #pragma alloca
-#else /* not MSDOS, __TURBOC__, or _AIX */
-#ifdef __hpux
-#ifdef __cplusplus
-extern "C" {
-void *alloca (unsigned int);
-};
-#else /* not __cplusplus */
-void *alloca ();
-#endif /* not __cplusplus */
-#endif /* __hpux */
-#endif /* not _AIX */
-#endif /* not MSDOS, or __TURBOC__ */
-#endif /* not sparc.  */
-#endif /* not GNU C.  */
-#endif /* alloca not defined.  */
-
 /* This is the parser code that is written into each bison parser
   when the %semantic_parser declaration is not specified in the grammar.
   It was written by Richard Stallman by simplifying the hairy parser
   used when %semantic_parser is specified.  */
 
+#ifndef YYSTACK_USE_ALLOCA
+#ifdef alloca
+#define YYSTACK_USE_ALLOCA
+#else /* alloca not defined */
+#ifdef __GNUC__
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#else /* not GNU C.  */
+#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi) || (defined (__sun) && defined (__i386))
+#define YYSTACK_USE_ALLOCA
+#include <alloca.h>
+#else /* not sparc */
+/* We think this test detects Watcom and Microsoft C.  */
+/* This used to test MSDOS, but that is a bad idea
+   since that symbol is in the user namespace.  */
+#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
+#if 0 /* No need for malloc.h, which pollutes the namespace;
+	 instead, just don't use alloca.  */
+#include <malloc.h>
+#endif
+#else /* not MSDOS, or __TURBOC__ */
+#if defined(_AIX)
+/* I don't know what this was needed for, but it pollutes the namespace.
+   So I turned it off.   rms, 2 May 1997.  */
+/* #include <malloc.h>  */
+ #pragma alloca
+#define YYSTACK_USE_ALLOCA
+#else /* not MSDOS, or __TURBOC__, or _AIX */
+#if 0
+#ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
+		 and on HPUX 10.  Eventually we can turn this on.  */
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#endif /* __hpux */
+#endif
+#endif /* not _AIX */
+#endif /* not MSDOS, or __TURBOC__ */
+#endif /* not sparc */
+#endif /* not GNU C */
+#endif /* alloca not defined */
+#endif /* YYSTACK_USE_ALLOCA not defined */
+
+#ifdef YYSTACK_USE_ALLOCA
+#define YYSTACK_ALLOC alloca
+#else
+#define YYSTACK_ALLOC malloc
+#endif
+
 /* Note: there must be only one dollar sign in this file.
    It is replaced by the list of actions, each action
    as one case of the switch.  */
@@ -340,8 +364,8 @@ void *alloca ();
 #define yyclearin	(yychar = YYEMPTY)
 #define YYEMPTY		-2
 #define YYEOF		0
-#define YYACCEPT	return(0)
-#define YYABORT 	return(1)
+#define YYACCEPT	goto yyacceptlab
+#define YYABORT 	goto yyabortlab
 #define YYERROR		goto yyerrlab1
 /* Like YYERROR except do call yyerror.
    This remains here temporarily to ease the
@@ -422,24 +446,24 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 10000
 #endif
-
-/* Prevent warning if -Wstrict-prototypes.  */
-#ifdef __GNUC__
-int yyparse (void);
-#endif
 
+/* Define __yy_memcpy.  Note that the size argument
+   should be passed with type unsigned int, because that is what the non-GCC
+   definitions require.  With GCC, __builtin_memcpy takes an arg
+   of type size_t, but it can handle unsigned int.  */
+
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
-#define __yy_memcpy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
+#define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
 #ifndef __cplusplus
 
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_memcpy (from, to, count)
-     char *from;
+__yy_memcpy (to, from, count)
      char *to;
-     int count;
+     char *from;
+     unsigned int count;
 {
   register char *f = from;
   register char *t = to;
@@ -454,10 +478,10 @@ __yy_memcpy (from, to, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_memcpy (char *from, char *to, int count)
+__yy_memcpy (char *to, char *from, unsigned int count)
 {
-  register char *f = from;
   register char *t = to;
+  register char *f = from;
   register int i = count;
 
   while (i-- > 0)
@@ -467,7 +491,7 @@ __yy_memcpy (char *from, char *to, int count)
 #endif
 #endif
 
-#line 192 "/usr/local/gnu/share/bison.simple"
+#line 217 "/usr/local/gnu/share/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -476,14 +500,29 @@ __yy_memcpy (char *from, char *to, int count)
    to the proper pointer type.  */
 
 #ifdef YYPARSE_PARAM
-#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
-#else
-#define YYPARSE_PARAM
+#ifdef __cplusplus
+#define YYPARSE_PARAM_ARG void *YYPARSE_PARAM
 #define YYPARSE_PARAM_DECL
+#else /* not __cplusplus */
+#define YYPARSE_PARAM_ARG YYPARSE_PARAM
+#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
+#endif /* not __cplusplus */
+#else /* not YYPARSE_PARAM */
+#define YYPARSE_PARAM_ARG
+#define YYPARSE_PARAM_DECL
+#endif /* not YYPARSE_PARAM */
+
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+#ifdef YYPARSE_PARAM
+int yyparse (void *);
+#else
+int yyparse (void);
+#endif
 #endif
 
 int
-yyparse(YYPARSE_PARAM)
+yyparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
 {
   register int yystate;
@@ -510,6 +549,7 @@ yyparse(YYPARSE_PARAM)
 #endif
 
   int yystacksize = YYINITDEPTH;
+  int yyfree_stacks = 0;
 
 #ifdef YYPURE
   int yychar;
@@ -594,18 +634,32 @@ yynewstate:
       if (yystacksize >= YYMAXDEPTH)
 	{
 	  yyerror("parser stack overflow");
+	  if (yyfree_stacks)
+	    {
+	      free (yyss);
+	      free (yyvs);
+#ifdef YYLSP_NEEDED
+	      free (yyls);
+#endif
+	    }
 	  return 2;
 	}
       yystacksize *= 2;
       if (yystacksize > YYMAXDEPTH)
 	yystacksize = YYMAXDEPTH;
-      yyss = (short *) alloca (yystacksize * sizeof (*yyssp));
-      __yy_memcpy ((char *)yyss1, (char *)yyss, size * sizeof (*yyssp));
-      yyvs = (YYSTYPE *) alloca (yystacksize * sizeof (*yyvsp));
-      __yy_memcpy ((char *)yyvs1, (char *)yyvs, size * sizeof (*yyvsp));
+#ifndef YYSTACK_USE_ALLOCA
+      yyfree_stacks = 1;
+#endif
+      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
+      __yy_memcpy ((char *)yyss, (char *)yyss1,
+		   size * (unsigned int) sizeof (*yyssp));
+      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
+      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
+		   size * (unsigned int) sizeof (*yyvsp));
 #ifdef YYLSP_NEEDED
-      yyls = (YYLTYPE *) alloca (yystacksize * sizeof (*yylsp));
-      __yy_memcpy ((char *)yyls1, (char *)yyls, size * sizeof (*yylsp));
+      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
+      __yy_memcpy ((char *)yyls, (char *)yyls1,
+		   size * (unsigned int) sizeof (*yylsp));
 #endif
 #endif /* no yyoverflow */
 
@@ -766,84 +820,84 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 112 "../../fsinfo/fsi_gram.y"
+#line 128 "../../fsinfo/fsi_gram.y"
 { yyval.q = new_que(); ;
     break;}
 case 2:
-#line 115 "../../fsinfo/fsi_gram.y"
+#line 131 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].h) ins_que((qelem *) yyvsp[0].h, list_of_hosts->q_back);
 	    yyval.q = yyvsp[-1].q; ;
     break;}
 case 3:
-#line 119 "../../fsinfo/fsi_gram.y"
+#line 135 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].a) ins_que((qelem *) yyvsp[0].a, list_of_automounts->q_back);
 	    yyval.q = yyvsp[-1].q; ;
     break;}
 case 4:
-#line 130 "../../fsinfo/fsi_gram.y"
+#line 146 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; ;
     break;}
 case 5:
-#line 133 "../../fsinfo/fsi_gram.y"
+#line 149 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; ;
     break;}
 case 6:
-#line 139 "../../fsinfo/fsi_gram.y"
+#line 155 "../../fsinfo/fsi_gram.y"
 { yyval.h = new_host(); set_host(yyval.h, HF_HOST, yyvsp[0].s); ;
     break;}
 case 7:
-#line 142 "../../fsinfo/fsi_gram.y"
+#line 158 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_HOST, yyvsp[0].s); ;
     break;}
 case 8:
-#line 148 "../../fsinfo/fsi_gram.y"
+#line 164 "../../fsinfo/fsi_gram.y"
 { yyval.h = new_host(); ;
     break;}
 case 9:
-#line 151 "../../fsinfo/fsi_gram.y"
+#line 167 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[-1].e) {
 		yyvsp[-1].e->e_if = yyvsp[-3].s;
 		yyval.h = yyvsp[-5].h; set_host(yyval.h, HF_ETHER, (char *) yyvsp[-1].e); }
 	  ;
     break;}
 case 10:
-#line 157 "../../fsinfo/fsi_gram.y"
+#line 173 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_CONFIG, yyvsp[0].s); ;
     break;}
 case 11:
-#line 160 "../../fsinfo/fsi_gram.y"
+#line 176 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_ARCH, yyvsp[0].s); ;
     break;}
 case 12:
-#line 163 "../../fsinfo/fsi_gram.y"
+#line 179 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_OS, yyvsp[0].s); ;
     break;}
 case 13:
-#line 166 "../../fsinfo/fsi_gram.y"
+#line 182 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_CLUSTER, yyvsp[0].s); ;
     break;}
 case 14:
-#line 169 "../../fsinfo/fsi_gram.y"
+#line 185 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown host attribute"); ;
     break;}
 case 15:
-#line 174 "../../fsinfo/fsi_gram.y"
+#line 190 "../../fsinfo/fsi_gram.y"
 { yyval.e = new_ether_if(); ;
     break;}
 case 16:
-#line 177 "../../fsinfo/fsi_gram.y"
+#line 193 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_INADDR, yyvsp[0].s); ;
     break;}
 case 17:
-#line 179 "../../fsinfo/fsi_gram.y"
+#line 195 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_NETMASK, yyvsp[0].s); ;
     break;}
 case 18:
-#line 181 "../../fsinfo/fsi_gram.y"
+#line 197 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_HWADDR, yyvsp[0].s); ;
     break;}
 case 19:
-#line 191 "../../fsinfo/fsi_gram.y"
+#line 207 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].q) {
 		yyval.a = new_auto_tree(yyvsp[-1].s, yyvsp[0].q);
 	    } else {
@@ -852,23 +906,23 @@ case 19:
 	  ;
     break;}
 case 20:
-#line 199 "../../fsinfo/fsi_gram.y"
+#line 215 "../../fsinfo/fsi_gram.y"
 { yyval.a = 0; ;
     break;}
 case 21:
-#line 204 "../../fsinfo/fsi_gram.y"
+#line 220 "../../fsinfo/fsi_gram.y"
 { yyval.s = strdup(""); ;
     break;}
 case 22:
-#line 207 "../../fsinfo/fsi_gram.y"
+#line 223 "../../fsinfo/fsi_gram.y"
 { yyval.s = yyvsp[0].s; ;
     break;}
 case 23:
-#line 212 "../../fsinfo/fsi_gram.y"
+#line 228 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; ;
     break;}
 case 24:
-#line 215 "../../fsinfo/fsi_gram.y"
+#line 231 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].d) {
 		if (yyvsp[-1].q)
 			yyval.q = yyvsp[-1].q;
@@ -881,55 +935,55 @@ case 24:
 	  ;
     break;}
 case 25:
-#line 234 "../../fsinfo/fsi_gram.y"
+#line 250 "../../fsinfo/fsi_gram.y"
 { yyvsp[-1].d->d_dev = yyvsp[-3].s; yyval.d = yyvsp[-1].d; ;
     break;}
 case 26:
-#line 237 "../../fsinfo/fsi_gram.y"
+#line 253 "../../fsinfo/fsi_gram.y"
 { yyval.d = (disk_fs *) 0; ;
     break;}
 case 27:
-#line 253 "../../fsinfo/fsi_gram.y"
+#line 269 "../../fsinfo/fsi_gram.y"
 { yyval.d = new_disk_fs(); ;
     break;}
 case 28:
-#line 256 "../../fsinfo/fsi_gram.y"
+#line 272 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FSTYPE, yyvsp[0].s); ;
     break;}
 case 29:
-#line 259 "../../fsinfo/fsi_gram.y"
+#line 275 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_OPTS, yyvsp[0].s); ;
     break;}
 case 30:
-#line 262 "../../fsinfo/fsi_gram.y"
+#line 278 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_PASSNO, yyvsp[0].s); ;
     break;}
 case 31:
-#line 265 "../../fsinfo/fsi_gram.y"
+#line 281 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FREQ, yyvsp[0].s); ;
     break;}
 case 32:
-#line 268 "../../fsinfo/fsi_gram.y"
+#line 284 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-2].d; set_disk_fs(yyval.d, DF_MOUNT, (char *) yyvsp[0].q); ;
     break;}
 case 33:
-#line 271 "../../fsinfo/fsi_gram.y"
+#line 287 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_DUMPSET, yyvsp[0].s); ;
     break;}
 case 34:
-#line 274 "../../fsinfo/fsi_gram.y"
+#line 290 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_LOG, yyvsp[0].s); ;
     break;}
 case 35:
-#line 277 "../../fsinfo/fsi_gram.y"
+#line 293 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown filesystem attribute"); ;
     break;}
 case 36:
-#line 291 "../../fsinfo/fsi_gram.y"
+#line 307 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; ;
     break;}
 case 37:
-#line 294 "../../fsinfo/fsi_gram.y"
+#line 310 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-3].s);
 	    a->a_volname = yyvsp[0].s;
 	    a->a_opts = yyvsp[-2].s;
@@ -941,7 +995,7 @@ case 37:
 	  ;
     break;}
 case 38:
-#line 304 "../../fsinfo/fsi_gram.y"
+#line 320 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-3].s);
             a->a_hardwiredfs = yyvsp[0].s;
             a->a_opts = yyvsp[-2].s;
@@ -953,7 +1007,7 @@ case 38:
           ;
     break;}
 case 39:
-#line 315 "../../fsinfo/fsi_gram.y"
+#line 331 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-2].s);
 	    a->a_symlink = yyvsp[0].s;
 	    if (yyvsp[-3].q)
@@ -964,7 +1018,7 @@ case 39:
 	  ;
     break;}
 case 40:
-#line 325 "../../fsinfo/fsi_gram.y"
+#line 341 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-4].s);
 	    a->a_mount = yyvsp[-1].q;
 	    a->a_opts = yyvsp[-3].s;
@@ -976,11 +1030,11 @@ case 40:
 	  ;
     break;}
 case 41:
-#line 338 "../../fsinfo/fsi_gram.y"
+#line 354 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; ;
     break;}
 case 42:
-#line 341 "../../fsinfo/fsi_gram.y"
+#line 357 "../../fsinfo/fsi_gram.y"
 { yyvsp[-2].m->m_mount = yyvsp[-1].q;
 	    yyvsp[-2].m->m_name = yyvsp[-4].s;
 	    if (yyvsp[-4].s[0] != '/' && yyvsp[-4].s[1] && strchr(yyvsp[-4].s+1, '/'))
@@ -993,31 +1047,31 @@ case 42:
 	  ;
     break;}
 case 43:
-#line 355 "../../fsinfo/fsi_gram.y"
+#line 371 "../../fsinfo/fsi_gram.y"
 { yyval.m = new_mount(); ;
     break;}
 case 44:
-#line 358 "../../fsinfo/fsi_gram.y"
+#line 374 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_EXPORTFS, yyvsp[0].s); ;
     break;}
 case 45:
-#line 361 "../../fsinfo/fsi_gram.y"
+#line 377 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_VOLNAME, yyvsp[0].s); ;
     break;}
 case 46:
-#line 364 "../../fsinfo/fsi_gram.y"
+#line 380 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_SEL, yyvsp[0].s); ;
     break;}
 case 47:
-#line 367 "../../fsinfo/fsi_gram.y"
+#line 383 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown directory attribute"); ;
     break;}
 case 48:
-#line 377 "../../fsinfo/fsi_gram.y"
+#line 393 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; ;
     break;}
 case 49:
-#line 380 "../../fsinfo/fsi_gram.y"
+#line 396 "../../fsinfo/fsi_gram.y"
 { set_fsmount(yyvsp[0].f, FM_VOLNAME, yyvsp[-1].s);
 	    if (yyvsp[-3].q)
 		yyval.q = yyvsp[-3].q;
@@ -1027,36 +1081,36 @@ case 49:
 	    ;
     break;}
 case 50:
-#line 400 "../../fsinfo/fsi_gram.y"
+#line 416 "../../fsinfo/fsi_gram.y"
 { yyval.f = new_fsmount(); ;
     break;}
 case 51:
-#line 403 "../../fsinfo/fsi_gram.y"
+#line 419 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-1].f; set_fsmount(yyval.f, FM_DIRECT, ""); ;
     break;}
 case 52:
-#line 406 "../../fsinfo/fsi_gram.y"
+#line 422 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_LOCALNAME, yyvsp[0].s); ;
     break;}
 case 53:
-#line 409 "../../fsinfo/fsi_gram.y"
+#line 425 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FROM, yyvsp[0].s); ;
     break;}
 case 54:
-#line 412 "../../fsinfo/fsi_gram.y"
+#line 428 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FSTYPE, yyvsp[0].s); ;
     break;}
 case 55:
-#line 415 "../../fsinfo/fsi_gram.y"
+#line 431 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_OPTS, yyvsp[0].s); ;
     break;}
 case 56:
-#line 418 "../../fsinfo/fsi_gram.y"
+#line 434 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown mount attribute"); ;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 487 "/usr/local/gnu/share/bison.simple"
+#line 543 "/usr/local/gnu/share/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1251,5 +1305,29 @@ yyerrhandle:
 
   yystate = yyn;
   goto yynewstate;
+
+ yyacceptlab:
+  /* YYACCEPT comes here.  */
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+  return 0;
+
+ yyabortlab:
+  /* YYABORT comes here.  */
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+  return 1;
 }
-#line 420 "../../fsinfo/fsi_gram.y"
+#line 436 "../../fsinfo/fsi_gram.y"
